@@ -220,20 +220,20 @@ pub mod macros {
             v2
         }};
     }
-    /// vec_as_string!() used to
+    /// vec_element_to_string!() used to
     /// convert vec item to String,
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
     /// return Vec\<String\>
     /// ```rust
-    ///let v1 = vec_as_string!(vec!["15.", "2.9"]);
-    ///let v2 = vec_as_string!(vec![15, 2]);
-    ///let v3 = vec_as_string!(vec![0.15, 0.2]);
+    ///let v1 = vec_element_to_string!(vec!["15.", "2.9"]);
+    ///let v2 = vec_element_to_string!(vec![15, 2]);
+    ///let v3 = vec_element_to_string!(vec![0.15, 0.2]);
     ///assert_eq!(vec!["15.", "2.9"], v1);
     ///assert_eq!(vec!["15", "2"], v2);
     ///assert_eq!(vec!["0.15", "0.2"], v3);
     /// ```
     #[macro_export]
-    macro_rules! vec_as_string {
+    macro_rules! vec_element_to_string {
         ($vec:expr) => {{
             let mut v2: Vec<String> = Vec::new();
             if $vec.len() > 0 {
@@ -333,6 +333,65 @@ pub mod macros {
             multiply_matrix(&vec1, &vec2)
         }};
     }
+    /// vec_element_remove!() used to
+    /// find the element fist position and remove
+    /// if not fond the element return original vec
+    /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
+    /// return return the same type
+    /// ```rust
+    ///let v1 = vec_element_remove!(vec!["15.", "2.9"], "2.9");
+    ///let v2 = vec_element_remove!(vec![15, 2, 3, 2], 2);
+    ///let v3 = vec_element_remove!(vec![0.15, 0.2, 0.2], 0.2);
+    ///assert_eq!(vec!["15."], v1);
+    ///assert_eq!(vec![15, 3, 2], v2);
+    ///assert_eq!(vec![0.15, 0.2], v3);
+    /// ```
+    #[macro_export]
+    macro_rules! vec_element_remove {
+        ($vec:expr,$element:expr) => {{
+            let mut vec = $vec.clone();
+            match &vec.binary_search_by(|probe| probe.partial_cmp(&$element).unwrap()) {
+                Ok(r) => {
+                    vec.remove(*r);
+                }
+                Err(r) => {}
+            }
+            vec
+        };};
+    }
+    /// vec_element_remove_all!() used to
+    /// find the element all position and remove
+    /// if not fond the element return original vec
+    /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
+    /// return return the same type
+    /// ```rust
+    ///let v1 = vec_element_remove_all!(vec!["15.", "2.9", "0.9", "2.9", "2.9"], "2.9");
+    ///assert_eq!(vec!["15.", "0.9"], v1);
+    ///let v2 = vec_element_remove_all!(vec![15, 2, 3, 2], 2);
+    ///assert_eq!(vec![15, 3], v2);
+    ///let v3 = vec_element_remove_all!(vec![0.15, 0.2, 1.0, 0.2], 0.3);
+    ///assert_eq!(vec![0.15, 0.2, 1.0, 0.2], v3);
+    /// ```
+    #[macro_export]
+    macro_rules! vec_element_remove_all {
+        ($vec:expr,$element:expr) => {{
+            let mut vec = $vec.clone();
+            fn remove<T: Copy + PartialOrd<T>>(vec: Vec<T>, target: &T) -> Vec<T> {
+                let mut v1 = vec.clone();
+                for i in 1..v1.len() - 1 {
+                    if v1[i - 1] == *target {
+                        v1.remove(i - 1);
+                    }
+                    // dbg!(&i);
+                }
+                if v1[v1.len() - 1] == *target {
+                    v1.remove(v1.len() - 1);
+                }
+                v1
+            }
+            remove(vec, &$element)
+        };};
+    }
     pub fn run() {}
 }
 
